@@ -11,6 +11,7 @@ from pipelime.commands.general import (
     SortCommand,
     FilterCommand,
     SliceCommand,
+    SetMetadataCommand,
 )
 from pipelime.commands.shell import ShellCommand
 from pipelime.commands.split_ops import (
@@ -20,3 +21,4 @@ from pipelime.commands.split_ops import (
 )
 from pipelime.commands.toy_dataset import ToyDatasetCommand
 from pipelime.commands.piper import RunCommand, DrawCommand, WatchCommand
+from pipelime.commands.tempman import TempCommand
