@@ -1,6 +1,12 @@
-from pipelime.stages.base import SampleStage, StageCompose, StageIdentity, StageLambda, StageInput
+from pipelime.stages.base import (
+    SampleStage,
+    StageCompose,
+    StageIdentity,
+    StageLambda,
+    StageInput,
+)
 from pipelime.stages.augmentations import StageAlbumentations
-from pipelime.stages.item_replacement import StageReplaceItem
+from pipelime.stages.item_replacement import StageReplaceItem, StageSetMetadata
 from pipelime.stages.item_sources import StageForgetSource, StageUploadToRemote
 from pipelime.stages.key_transformations import (
     StageDuplicateKey,
